@@ -25,6 +25,16 @@
 #' @template band_mappings
 "landsat_band_mapping"
 
+#' ALOS PALSAR band mapping
+#'
+#' This object is a named list of character vectors, with names corresponding to
+#' Landsat band names and values corresponding to band names in
+#' `spectral_indices`.
+#'
+#' @template band_mappings
+"alos_palsar_band_mapping"
+
+
 #' Landsat band mapping
 #'
 #' This object is structured slightly differently from other band mapping
